%bcond_with simd

Name:           mame
Version:        0153s
Release:        %mkrel 1
Summary:        Multiple Arcade Machine Emulator
License:        MAME License and BSD
URL:            http://mamedev.org/
Group:		Emulators
Source0:        http://mamedev.org/downloader.php?file=releases/%{name}%{version}.exe
Patch0:         %{name}-fortify.patch
Patch2:         %{name}-verbosebuild.patch
BuildRequires:  expat-devel
BuildRequires:  %{_lib}flac8-devel
BuildRequires:  %{_lib}jpeg-devel
BuildRequires:  p7zip
BuildRequires:  portmidi-devel
BuildRequires:  python
BuildRequires:  qt-devel
BuildRequires:  SDL_ttf-devel
BuildRequires:  zlib-devel
Provides:       bundled(lzma-sdk) = 9.22

%description
MAME stands for Multiple Arcade Machine Emulator.  When used in conjunction
with an arcade game's data files (ROMs), MAME will more or less faithfully
reproduce that game on a PC.

The ROM images that MAME utilizes are "dumped" from arcade games' original
circuit-board ROM chips.  MAME becomes the "hardware" for the games, taking
the place of their original CPUs and support chips.  Therefore, these games
are NOT simulations, but the actual, original games that appeared in arcades.

MAME's purpose is to preserve these decades of video-game history.  As gaming
technology continues to rush forward, MAME prevents these important "vintage"
games from being lost and forgotten.  This is achieved by documenting the
hardware and how it functions, thanks to the talent of programmers from the
MAME team and from other contributors.  Being able to play the games is just
a nice side-effect, which doesn't happen all the time.  MAME strives for
emulating the games faithfully.

D/L free roms from http://www.mamedev.org/roms/ and
put them in ~/roms folder

Please also have a look at mame-tools, mess, and mess-tools

%package tools
Summary:        Additional tools for MAME
Requires:       %{name} = %{version}-%{release}
Group:		Emulators

%description tools
%{summary}.


%package -n mess
Summary:        Multi Emulator Super System
Provides:       bundled(lzma-sdk) = 9.22
Group:		Emulators

%description -n mess
MESS is an acronym that stands for Multi Emulator Super System. MESS will
more or less faithfully reproduce computer and console systems on a PC.

MESS emulates the hardware of the systems and sometimes utilizes ROM images to
load programs and games.  Therefore, these systems are NOT simulations, but
the actual emulations of the hardware.

%package -n mess-tools
Summary:        Additional tools for MESS
Requires:       mess = %{version}-%{release}
Group:		Emulators

%description -n mess-tools
%{summary}.


%prep
%setup -qcT
for sourcefile in %{sources}; do
    7za x $sourcefile
done
find . -type f -not -name *.png -exec sed -i 's/\r//' {} \;
%patch0 -p1 -b .fortify
%patch2 -p1 -b .verbosebuild

# Fix encoding
for whatsnew in whatsnew.txt messnew.txt; do
    iconv -f iso8859-1 -t utf-8 $whatsnew > $whatsnew.conv
    mv -f $whatsnew.conv $whatsnew
done

# Create ini files
cat > %{name}.ini << EOF
# Define multi-user paths
artpath            %{_datadir}/%{name}/artwork;%{_datadir}/%{name}/effects
cheatpath          %{_datadir}/%{name}/cheat
ctrlrpath          %{_datadir}/%{name}/ctrlr
fontpath           %{_datadir}/%{name}/fonts
hashpath           %{_datadir}/%{name}/hash
rompath            %{_datadir}/%{name}/roms;%{_datadir}/%{name}/chds
samplepath         %{_datadir}/%{name}/samples

# Allow user to override ini settings
inipath            \$HOME/.%{name}/ini;%{_sysconfdir}/%{name}

# Set paths for local storage
cfg_directory      \$HOME/.%{name}/cfg
comment_directory  \$HOME/.%{name}/comments
diff_directory     \$HOME/.%{name}/diff
input_directory    \$HOME/.%{name}/inp
memcard_directory  \$HOME/.%{name}/memcard
nvram_directory    \$HOME/.%{name}/nvram
snapshot_directory \$HOME/.%{name}/snap
state_directory    \$HOME/.%{name}/sta
video              opengl
autosave           1
EOF

#make a copy for MESS
sed 's/%{name}/mess/g' %{name}.ini > mess.ini

%if %{with simd}
sed -i 's/USE_SIMD        (0)/USE_SIMD        (1)/' src/emu/cpu/rsp/rsp.h
%endif

%build
#these flags are already included in the Makefile
RPM_OPT_FLAGS=$(echo $RPM_OPT_FLAGS | sed -e 's/-O2 -g -pipe -Wall //')

%if %{with simd}
RPM_OPT_FLAGS=$(echo $RPM_OPT_FLAGS | sed -e 's/-mtune=generic/-march=corei7-avx/')
%endif

#save some space
MAME_FLAGS="NOWERROR=1 SYMBOLS=1 OPTIMIZE=2 BUILD_EXPAT=0 BUILD_ZLIB=0 \
    BUILD_FLAC=0 BUILD_JPEGLIB=0 BUILD_MIDILIB=0 SUFFIX64="

make %{?_smp_mflags} $MAME_FLAGS TARGET=ldplayer \
    OPT_FLAGS="$RPM_OPT_FLAGS -DINI_PATH='\"%{_sysconfdir}/%{name};\"'"
make %{?_smp_mflags} $MAME_FLAGS \
    OPT_FLAGS="$RPM_OPT_FLAGS -DINI_PATH='\"%{_sysconfdir}/%{name};\"'" all
find obj -type f -not -name \*.lh -and -not -name drivlist.c -exec rm {} \;
make %{?_smp_mflags} $MAME_FLAGS TARGET=mess\
    OPT_FLAGS="$RPM_OPT_FLAGS -DINI_PATH='\"%{_sysconfdir}/mess;\"'" all


%install
rm -rf $RPM_BUILD_ROOT

# create directories
install -d $RPM_BUILD_ROOT%{_sysconfdir}/%{name}
install -d $RPM_BUILD_ROOT%{_sysconfdir}/mess
for folder in cfg comments diff ini inp memcard nvram snap sta
do
    install -d $RPM_BUILD_ROOT%{_sysconfdir}/skel/.%{name}/$folder
    install -d $RPM_BUILD_ROOT%{_sysconfdir}/skel/.mess/$folder
done
install -d $RPM_BUILD_ROOT%{_bindir}
for folder in artwork chds cheats ctrlr effects fonts hash hlsl keymaps roms \
    samples shader
do
    install -d $RPM_BUILD_ROOT%{_datadir}/%{name}/$folder
done
for folder in artwork chds cheats ctrlr effects fonts hash hlsl keymaps roms \
    samples shader software
do
    install -d $RPM_BUILD_ROOT%{_datadir}/mess/$folder
done
install -d $RPM_BUILD_ROOT%{_mandir}/man1
install -d $RPM_BUILD_ROOT%{_mandir}/man6

# install files
install -pm 644 %{name}.ini $RPM_BUILD_ROOT%{_sysconfdir}/%{name}
install -pm 644 mess.ini $RPM_BUILD_ROOT%{_sysconfdir}/mess
install -pm 755 ldplayer $RPM_BUILD_ROOT%{_bindir}
install -pm 755 %{name} $RPM_BUILD_ROOT%{_bindir}
install -pm 755 mess $RPM_BUILD_ROOT%{_bindir}
install -pm 755 chdman jedutil ldresample ldverify romcmp testkeys unidasm \
    castool floptool imgtool pngcmp nltool $RPM_BUILD_ROOT%{_bindir}
for tool in regrep split src2html srcclean
do
    install -pm 755 $tool $RPM_BUILD_ROOT%{_bindir}/%{name}-$tool
done
install -pm 644 artwork/* $RPM_BUILD_ROOT%{_datadir}/%{name}/artwork
install -pm 644 hash/* $RPM_BUILD_ROOT%{_datadir}/%{name}/hash
install -pm 644 hlsl/* $RPM_BUILD_ROOT%{_datadir}/%{name}/hlsl
install -pm 644 keymaps/* $RPM_BUILD_ROOT%{_datadir}/%{name}/keymaps
pushd src/osd/sdl
install -pm 644 shader/*.?sh $RPM_BUILD_ROOT%{_datadir}/%{name}/shader
for folder in artwork hash hlsl keymaps shader
do
    pushd $RPM_BUILD_ROOT%{_datadir}/%{name}/$folder
    for i in *
    do
        ln -s ../../%{name}/$folder/$i ../../mess/$folder/$i
    done
    popd
done
pushd man
install -pm 644 ldplayer.1 $RPM_BUILD_ROOT%{_mandir}/man1
install -pm 644 castool.1 chdman.1 imgtool.1 jedutil.1 ldresample.1 ldverify.1 \
    romcmp.1 testkeys.1 $RPM_BUILD_ROOT%{_mandir}/man1
install -pm 644 mame.6 mess.6 $RPM_BUILD_ROOT%{_mandir}/man6
popd
popd


%files
%defattr(-,root,root,-)
%doc docs/config.txt docs/hlsl.txt docs/license.txt docs/mame.txt
%doc docs/newvideo.txt docs/nscsi.txt
%doc whatsnew*.txt
%config(noreplace) %{_sysconfdir}/%{name}/%{name}.ini
%dir %{_sysconfdir}/%{name}
%{_sysconfdir}/skel/.%{name}
%{_bindir}/%{name}
%{_mandir}/man6/mame.6*
%{_datadir}/%{name}


%files tools
%defattr(-,root,root,-)
%{_bindir}/chdman
%{_bindir}/jedutil
%{_bindir}/ldplayer
%{_bindir}/ldresample
%{_bindir}/ldverify
%{_bindir}/%{name}-regrep
%{_bindir}/nltool
%{_bindir}/pngcmp
%{_bindir}/romcmp
%{_bindir}/%{name}-split
%{_bindir}/%{name}-src2html
%{_bindir}/%{name}-srcclean
%{_bindir}/testkeys
%{_bindir}/unidasm
%{_mandir}/man1/chdman.1*
%{_mandir}/man1/jedutil.1*
%{_mandir}/man1/ldresample.1*
%{_mandir}/man1/ldverify.1*
%{_mandir}/man1/romcmp.1*
%{_mandir}/man1/testkeys.1*
%{_mandir}/man1/ldplayer.1*


%files -n mess
%defattr(-,root,root,-)
%doc messnew*.txt
%config(noreplace) %{_sysconfdir}/mess/mess.ini
%dir %{_sysconfdir}/mess
%{_sysconfdir}/skel/.mess
%{_bindir}/mess
%{_mandir}/man6/mess.6*
%{_datadir}/mess

%files -n mess-tools
%defattr(-,root,root,-)
%doc docs/imgtool.txt
%{_bindir}/castool
%{_bindir}/floptool
%{_bindir}/imgtool
%{_mandir}/man1/castool.1*
%{_mandir}/man1/imgtool.1*


%changelog
* Mon Apr 21 2014 pinoc <vogtpet at gmail.com> 0153s-1pclos2014
- 0153 reimported from Fedora

* Sun Dec 29 2013 MBantz <martin dot bantz at gmail dot com> mame-0149s-1pclinuxos2014
- Created for PCLinuxOS



